@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2006  NTT DATA CORPORATION
  *
- * Version: 1.1.3   2006/07/13
+ * Version: 1.3   2006/11/11
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -501,7 +501,7 @@ static int Syaoran_Initialize(struct super_block *sb, void *data)
 	static int first = 1;
 	if (first) {
 		first = 0;
-		printk("SYAORAN: 1.1.3   2006/07/13\n");
+		printk("SYAORAN: 1.3   2006/11/11\n");
 	}
 	{
 		struct inode *inode = new_inode(sb);
@@ -634,6 +634,55 @@ static int CheckFlags(struct syaoran_sb_info *info, struct dentry *dentry, int m
 			break;
 		}
 	}
+	if (error && strlen(filename) < (sizeof(filename) / 4) - 16) {
+		const char *name;
+		const uid_t uid = current->fsuid;
+		const gid_t gid = current->fsgid;
+		const mode_t perm = mode & 0777;
+		flags &= ~DEVICE_USED;
+		{
+			char *end = filename + sizeof(filename) - 1;
+			const char *cp = strchr(filename, '\0') - 1;
+			while (cp > filename) {
+				const unsigned char c = *cp--;
+				if (c == '\\') {
+					*--end = '\\';
+					*--end = '\\';
+				} else if (c > ' ' && c < 127) {
+					*--end = c;
+				} else {
+					*--end = (c & 7) + '0';
+					*--end = ((c >> 3) & 7) + '0';
+					*--end = (c >> 6) + '0';
+					*--end = '\\';
+				}
+			}
+			name = end;
+		}
+		switch (mode & S_IFMT) {
+		case S_IFCHR:
+			printk(KERN_DEBUG "SYAORAN-ERROR: %s %3o %3u %3u %2u %c %3u %3u\n", name, perm, uid, gid, flags, 'c', MAJOR(dev), MINOR(dev));
+			break;
+		case S_IFBLK:
+			printk(KERN_DEBUG "SYAORAN-ERROR: %s %3o %3u %3u %2u %c %3u %3u\n", name, perm, uid, gid, flags, 'b', MAJOR(dev), MINOR(dev));
+			break;
+		case S_IFIFO:
+			printk(KERN_DEBUG "SYAORAN-ERROR: %s %3o %3u %3u %2u %c\n", name, perm, uid, gid, flags, 'p');
+			break;
+		case S_IFSOCK:
+			printk(KERN_DEBUG "SYAORAN-ERROR: %s %3o %3u %3u %2u %c\n", name, perm, uid, gid, flags, 's');
+			break;
+		case S_IFDIR:
+			printk(KERN_DEBUG "SYAORAN-ERROR: %s %3o %3u %3u %2u %c\n", name, perm, uid, gid, flags, 'd');
+			break;
+		case S_IFLNK:
+			printk(KERN_DEBUG "SYAORAN-ERROR: %s %3o %3u %3u %2u %c %s\n", name, perm, uid, gid, flags, 'l', "unknown");
+			break;
+		case S_IFREG:
+			printk(KERN_DEBUG "SYAORAN-ERROR: %s %3o %3u %3u %2u %c\n", name, perm, uid, gid, flags, 'f');
+			break;
+		}
+	}
 	spin_unlock(&lock);
 	return error;
 }
@@ -782,7 +831,9 @@ static int syaoran_create_tracelog(struct super_block *sb, const char *filename)
 			inode->i_mode = S_IFREG | 0400;
 			inode->i_uid = 0;
 			inode->i_gid = 0;
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,19)
 			inode->i_blksize = PAGE_CACHE_SIZE;
+#endif
 			inode->i_blocks = 0;
 			inode->i_mapping->a_ops = &syaoran_aops;
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,5,0)
