@@ -6,7 +6,7 @@
  *
  * Copyright (C) 2005-2006  NTT DATA CORPORATION
  *
- * Version: 1.3.1   2006/12/08
+ * Version: 1.3   2006/11/11
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -87,6 +87,7 @@ void __init CCSProc_Init(void)
 #ifdef CONFIG_TOMOYO
 	CreateEntry("domain_policy",    0600, policy_dir, CCS_POLICY_DOMAINPOLICY);
 	CreateEntry("exception_policy", 0600, policy_dir, CCS_POLICY_EXCEPTIONPOLICY);
+	CreateEntry("trusted_pids",     0400, info_dir, CCS_INFO_TRUSTEDPIDS);
 	CreateEntry(".domain_status",   0600, policy_dir, CCS_POLICY_DOMAIN_STATUS);
 	CreateEntry(".process_status",  0400, info_dir, CCS_INFO_PROCESS_STATUS);
 #ifdef CONFIG_TOMOYO_AUDIT
