@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2006  NTT DATA CORPORATION
  *
- * Version: 1.3.1   2006/12/08
+ * Version: 1.3   2006/11/11
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -168,6 +168,10 @@ static int CheckNetworkEntry(const int is_ipv6, const int operation, const u32 *
 	const int is_enforce = CheckCCSEnforce(CCS_TOMOYO_MAC_FOR_NETWORK);
 	const u32 ip = ntohl(*address); /* using host byte order to allow u32 comparison than memcmp().*/
 	if (!CheckCCSFlags(CCS_TOMOYO_MAC_FOR_NETWORK)) return 0;
+	if (GetDomainAttribute(domain) & DOMAIN_ATTRIBUTE_TRUSTED) {
+		AuditNetworkLog(is_ipv6, keyword, address, port, 1);
+		return 0;
+	}
 	for (ptr = domain->first_acl_ptr; ptr; ptr = ptr->next) {
 		if (is_ipv6) {
 			if (ptr->type_hash == type_hash && ((IPv6_NETWORK_ACL_RECORD *) ptr)->min_port <= port && port <= ((IPv6_NETWORK_ACL_RECORD *) ptr)->max_port && memcmp(((IPv6_NETWORK_ACL_RECORD *) ptr)->min_address, address, 16) <= 0 && memcmp(address, ((IPv6_NETWORK_ACL_RECORD *) ptr)->max_address, 16) <= 0 && CheckCondition(ptr->cond, NULL) == 0) break;
